@@ -24,12 +24,11 @@ def load_dotenv(
     """
     dotenv_vault = DotEnvVault()
     if dotenv_vault.dotenv_key:
-        logger.info('Getting .env from vault.')
+        logger.info('Loading env from encrypted .env.vault')
         vault_stream = dotenv_vault.parsed_vault()
         # we're going to override the .vault to any existing keys in local
         return load_dotenv_file(stream=vault_stream, override=True)
     else:
-        logger.info('Getting .env from local.')
         return load_dotenv_file(
             dotenv_path=dotenv_path,
             stream=stream, 
